-- Init
local frame = CreateFrame("FRAME", "TurnInEverything_Frame");
frame:RegisterEvent("GOSSIP_SHOW");
frame:RegisterEvent("QUEST_GREETING");
frame:RegisterEvent("QUEST_PROGRESS");
frame:RegisterEvent("QUEST_COMPLETE");
frame:RegisterEvent("MODIFIER_STATE_CHANGED");
local tie_TempDisable = false;

-- Event handler
local function eventHandler(self, event)
	if (event == "MODIFIER_STATE_CHANGED") then
		tie_ModiferChange(event);
	elseif (event == "QUEST_PROGRESS" or event == "QUEST_COMPLETE") then
		tie_QuestProgress(event);
	end
	
	-- Do not process other events if tie_TempDisable is set
	if (tie_TempDisable) then
		return;
	end

	if (event == "GOSSIP_SHOW") then
		tie_GossipShow();
	elseif (event == "QUEST_GREETING") then
		tie_QuestGreeting();
	end
end
frame:SetScript('OnEvent', eventHandler);

-- Call QuestProgress on each active quest
function tie_GossipShow()
	local q = { GetGossipActiveQuests() };
	local i = 1;
	local qNum = 1;
	while(q[i]) do
		SelectGossipActiveQuest(qNum);
		tie_QuestProgress();
		
		-- Increment the quest details and gossip indexes
        i = i + 3;
		qNum = qNum + 1;
    end
end

-- Call QuestProgress on each active quest
function tie_QuestGreeting()
	print('tie_QuestGreeting');
	local numQ = GetNumActiveQuests();
	for i=0,numQ do
		SelectActiveQuest(i);
		tie_QuestProgress();
    end
end

-- If this quest is completable, click continue and spew out text until we get to the completion screen
function tie_QuestProgress(event)
	-- If we're done with the progress text
	if (event == "QUEST_COMPLETE") then
		-- Display the reward text
		DEFAULT_CHAT_FRAME:AddMessage(GetTitleText() .. ' Reward: ' .. GetRewardText(), 1, 0.98, 0.8);
	
		-- Do not accept the reward if tie_TempDisable is set
		if (tie_TempDisable) then
			return;
		end
	
		-- If there's only one reward, grab it
		if (GetNumQuestChoices() < 2) then
			GetQuestReward(1);
		end

	-- If there's still progress text left
	else
		-- Bail if the quest is not completable
		if(not IsQuestCompletable()) then
			DeclineQuest();
			return;
		end

		-- And display the progress text
		DEFAULT_CHAT_FRAME:AddMessage(GetTitleText() .. ' Progress: ' .. GetProgressText(), 1, 0.98, 0.8);

		-- Do not complete the quest if tie_TempDisable is set
		if (tie_TempDisable) then
			return;
		end

		-- Otherwise click continue continue
		CompleteQuest();
	end
end

-- Temporarily disable processing if the hotkey is pressed
-- Currently hard-coded to shift, but abstracted to a function should I ever to to writing a UI to allow user configuration
function tie_ModiferChange(event)
	if (IsShiftKeyDown()) then
		tie_TempDisable = true;
	else
		tie_TempDisable = false;
	end
end